# Hexit
Simple python utility for creating HEX versions of binary files.
I needed a hex version of binary code to insert it in x64dbg so I created this script.

## Usage
```
python -m hexit [-h] -i INPUT [-o OUTPUT]

options:
  -h, --help            show this help message and exit
  -i INPUT, --input INPUT
                        Input .bin file
  -o OUTPUT, --output OUTPUT
                        Output .hex file```

